package net.minecraft.network.play.server;

import java.io.IOException;
import net.minecraft.entity.Entity;
import net.minecraft.network.Packet;
import net.minecraft.network.PacketBuffer;
import net.minecraft.network.play.INetHandlerPlayClient;
import net.minecraft.world.World;

public class S14PacketEntity implements Packet<INetHandlerPlayClient> {
	protected int entityId;
	protected int posX;
	protected int posY;
	protected int posZ;
	protected byte yaw;
	protected byte pitch;
	protected boolean onGround;
	protected boolean rotating;

	public S14PacketEntity() {
	}

	public S14PacketEntity(int entityIdIn) {
		this.entityId = entityIdIn;
	}

	/**
	 * Reads the raw packet data from the data stream.
	 */
	public void readPacketData(PacketBuffer buf) throws IOException {
		this.entityId = buf.readVarIntFromBuffer();
	}

	/**
	 * Writes the raw packet data to the data stream.
	 */
	public void writePacketData(PacketBuffer buf) throws IOException {
		buf.writeVarIntToBuffer(this.entityId);
	}

	/**
	 * Passes this Packet on to the NetHandler for processing.
	 */
	public void processPacket(INetHandlerPlayClient handler) {
		handler.handleEntityMovement(this);
	}

	public String toString() {
		return "Entity_" + super.toString();
	}

	public Entity getEntity(World worldIn) {
		return worldIn.getEntityByID(this.entityId);
	}

	public int getX() {
		return this.posX;
	}

	public int getY() {
		return this.posY;
	}

	public int getZ() {
		return this.posZ;
	}

	public byte getYaw() {
		return this.yaw;
	}

	public byte getPitch() {
		return this.pitch;
	}

	public boolean isRotating() {
		return this.rotating;
	}

	public boolean getOnGround() {
		return this.onGround;
	}

	public static class S15PacketEntityRelMove extends S14PacketEntity {
		public S15PacketEntityRelMove() {
		}

		public S15PacketEntityRelMove(int entityIdIn, long xIn, long yIn, long zIn, boolean onGroundIn) {
			super(entityIdIn);
			this.posX = (int) xIn;
			this.posY = (int) yIn;
			this.posZ = (int) zIn;
			this.onGround = onGroundIn;
		}

		public void readPacketData(PacketBuffer buf) throws IOException {
			super.readPacketData(buf);
			this.posX = buf.readShort();
			this.posY = buf.readShort();
			this.posZ = buf.readShort();
			this.onGround = buf.readBoolean();
		}

		public void writePacketData(PacketBuffer buf) throws IOException {
			super.writePacketData(buf);
			buf.writeShort(this.posX);
			buf.writeShort(this.posY);
			buf.writeShort(this.posZ);
			buf.writeBoolean(this.onGround);
		}
	}

	public static class S16PacketEntityLook extends S14PacketEntity {
		public S16PacketEntityLook() {
			this.rotating = true;
		}

		public S16PacketEntityLook(int entityIdIn, byte yawIn, byte pitchIn, boolean onGroundIn) {
			super(entityIdIn);
			this.yaw = yawIn;
			this.pitch = pitchIn;
			this.rotating = true;
			this.onGround = onGroundIn;
		}

		public void readPacketData(PacketBuffer buf) throws IOException {
			super.readPacketData(buf);
			this.yaw = buf.readByte();
			this.pitch = buf.readByte();
			this.onGround = buf.readBoolean();
		}

		public void writePacketData(PacketBuffer buf) throws IOException {
			super.writePacketData(buf);
			buf.writeByte(this.yaw);
			buf.writeByte(this.pitch);
			buf.writeBoolean(this.onGround);
		}
	}

	public static class S17PacketEntityLookMove extends S14PacketEntity {
		public S17PacketEntityLookMove() {
			this.rotating = true;
		}

		public S17PacketEntityLookMove(int entityIdIn, long xIn, long yIn, long zIn, byte yawIn, byte pitchIn,
				boolean onGroundIn) {
			super(entityIdIn);
			this.posX = (int) xIn;
			this.posY = (int) yIn;
			this.posZ = (int) zIn;
			this.yaw = yawIn;
			this.pitch = pitchIn;
			this.onGround = onGroundIn;
			this.rotating = true;
		}

		public void readPacketData(PacketBuffer buf) throws IOException {
			super.readPacketData(buf);
			this.posX = buf.readShort();
			this.posY = buf.readShort();
			this.posZ = buf.readShort();
			this.yaw = buf.readByte();
			this.pitch = buf.readByte();
			this.onGround = buf.readBoolean();
		}

		public void writePacketData(PacketBuffer buf) throws IOException {
			super.writePacketData(buf);
			buf.writeShort(this.posX);
			buf.writeShort(this.posY);
			buf.writeShort(this.posZ);
			buf.writeByte(this.yaw);
			buf.writeByte(this.pitch);
			buf.writeBoolean(this.onGround);
		}
	}
}
